@@ -148,7 +148,7 @@ class FastGWR:
 
             if self.minbw is None:
                 self.minbw = 40 + 2 * self.k
-            if not init_mgwr:
+            if not init_mgwr and mgwr:
                 self.minbw = 40 + 2
                 
                 
@@ -210,7 +210,6 @@ class FastGWR:
         """
         Golden-section search bandwidth optimization
         """
-    
         delta = 0.38197
         b = a + delta * np.abs(c-a)
         d = c - delta * np.abs(c-a)
